
/********************************************
****       Awlib 1.1 - Glass window      ****
**** (c) 2002-2009 - Alessandro Pedretti ****
********************************************/

/*
 * AwLib usage:
 * ============
 * - Include awlib.h in your source code
 * - When you create a new window call AW_InitAlphaWin() with the window
 *   handle as argument.
 * - Remember to link the suitable link library for your compiler. Look in the
 *   specific directories:
 *   BCB     -> Borland C++ Builder 6
 *   Mingw32 -> Gcc - Mingw32 environment
 *   Win64   -> Visual C x64
 *
 * - If you want fade manually the window (e.g. when you click a button), call
 *   AW_FadeOut() with the window handle as argument.
 */

#ifndef AWLIB_H
#  define  AWLIB_H

/**** Constants ****/

#  define  AW_DELAY             50

#  ifndef WS_EX_LAYERED
#    define  WS_EX_LAYERED      0x80000
#  endif

#  ifndef LWA_ALPHA
#    define  LWA_ALPHA          2
#  endif

/**** Default parameters ****/

#  define  AW_DEF_FADESPEED     200
#  define  AW_DEF_ALPHAMIN      178
#  define  AW_DEF_ALPHAMAX      255
#  define  AW_DEF_ALPHAOPEN     100


/**** Definitions ****/

typedef struct _AW_WNDALPHA {
  struct _AW_WNDALPHA   *Ptr;           /* Pointer to next list item */
  HWND                  hWnd;           /* Window handle             */
  FARPROC               Proc;           /* Default process routine   */
  HANDLE                Thread;         /* Thread handle             */
  BYTE                  CurAlpha;       /* Current alpha value       */
  BYTE                  DestAlpha;      /* Final alpha value         */
} AW_WNDALPHA;


/**** Prototypes ****/

#  ifdef __cplusplus
extern "C" {
#  endif

void AW_EnableAll(BOOL);
/*
 * void AW_EnableAll(BOOL Val)
 *
 * It enables/disables the glass window function to all initialized
 * windows.
 */

void AW_FadeOut(HWND);
/*
 * void AW_FadeOut(HWND hWnd)
 *
 * Manual fade out function.
 */

AW_WNDALPHA *AW_InitAlphaWin(HWND);
/*
 * AW_WNDALPHA *AW_InitAlphaWin(HWND hWnd)
 *
 * This function add the glass capability to a specific window. The only
 * required argument is the window handle.
 * The return value is the pointer to the AW_WBDALPHA structure. It's NULL
 * if the function fails.
 */

void         AW_SetPar(BYTE, BYTE, BYTE, UINT);
/*
 * AW_SetPar(BYTE AlphaMax, BYTE AlphaMin, BYTE AlphaOpen, UINT FadeSpeed)
 *
 * Use this function to set de default parameters of the glass windows.
 * AlphaMax  = the maximum alpha at the end of the fade-in animation (def. 255).
 * AlplaMin  = the minimum alpha at the end of the fade-out animation (def. 178).
 * AlphaOpen = the starting alpha when the window is opened (def. 100).
 * FadeSpeed = speed in ms of the animation (def. 200).
 */

#  ifdef __cplusplus
}
#  endif
#endif
